==> krita_4.4.2+dfsg.orig.tar.xz: krita-4.4.2/libs/widgets/KisColorSelectorInterface.h <==
/*
 * Copyright (C) 2016 Boudewijn Rempt <boud@valdyas.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KISCOLORSELECTORINTERFACE_H
#define KISCOLORSELECTORINTERFACE_H

#include "kritawidgets_export.h"

#include <QWidget>
#include <KoColor.h>

class KoColorDisplayRendererInterface;
class KoColorSpace;

class KRITAWIDGETS_EXPORT KisColorSelectorInterface : public QWidget {
    Q_OBJECT
public:
    KisColorSelectorInterface(QWidget *parent = 0)
        : QWidget(parent)
    {}
    ~KisColorSelectorInterface() override {}
    virtual void setConfig(bool forceCircular, bool forceSelfUpdate)
    {
        Q_UNUSED(forceCircular);
        Q_UNUSED(forceSelfUpdate);
    }
    virtual void setDisplayRenderer (const KoColorDisplayRendererInterface *displayRenderer)
    {
        Q_UNUSED(displayRenderer);
    }

    virtual KoColor getCurrentColor() const = 0;

Q_SIGNALS:
    void sigNewColor(const KoColor &c);

public Q_SLOTS:
    virtual void slotSetColor(const KoColor &c) = 0;
    /**
     * @brief slotSetColorSpace
     * Set the color space the selector should cover
     *
     * This is mostly a hint to decide visual presentation.
     * Internal processing may be in a different color space and
     * input conversion shall be handled by the selector itself.
     * Calling this voids the currently selected color.
     */
    virtual void slotSetColorSpace(const KoColorSpace *cs);
};

#endif // KISCOLORSELECTORINTERFACE_H

==> krita_5.2.14+dfsg.orig.tar.xz: krita-5.2.14/libs/widgets/KisColorSelectorInterface.h <==
/*
 * SPDX-FileCopyrightText: 2016 Boudewijn Rempt <boud@valdyas.org>
 *
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef KISCOLORSELECTORINTERFACE_H
#define KISCOLORSELECTORINTERFACE_H

#include "kritawidgets_export.h"

#include <QWidget>
#include <KoColor.h>

class KoColorDisplayRendererInterface;
class KoColorSpace;

class KRITAWIDGETS_EXPORT KisColorSelectorInterface : public QWidget {
    Q_OBJECT
public:
    KisColorSelectorInterface(QWidget *parent = 0)
        : QWidget(parent)
    {
        // Color selectors don't have context menus. Setting this prevents any
        // long-presses from delaying inputs, see KisLongPressEventFilter.cpp.
        setContextMenuPolicy(Qt::PreventContextMenu);
    }
    ~KisColorSelectorInterface() override {}
    virtual void setConfig(bool forceCircular, bool forceSelfUpdate)
    {
        Q_UNUSED(forceCircular);
        Q_UNUSED(forceSelfUpdate);
    }
    virtual void setDisplayRenderer (const KoColorDisplayRendererInterface *displayRenderer)
    {
        Q_UNUSED(displayRenderer);
    }

    virtual KoColor getCurrentColor() const = 0;

Q_SIGNALS:
    void sigNewColor(const KoColor &c);

public Q_SLOTS:
    virtual void slotSetColor(const KoColor &c) = 0;
    /**
     * @brief slotSetColorSpace
     * Set the color space the selector should cover
     *
     * This is mostly a hint to decide visual presentation.
     * Internal processing may be in a different color space and
     * input conversion shall be handled by the selector itself.
     * Calling this voids the currently selected color.
     */
    virtual void slotSetColorSpace(const KoColorSpace *cs);
};

#endif // KISCOLORSELECTORINTERFACE_H
